@@ -3,7 +3,7 @@
 Debian related assertion
 '''
 
-from StringIO import StringIO
+from six import BytesIO
 
 from commodity.type_ import checked_type
 from commodity.os_ import SubProcess
@@ -16,8 +16,8 @@ class Package(Printable):
     def __init__(self, name):
         self.name = checked_type(str, name)
 
-    def __unicode__(self):
-        return unicode(self.name)
+    def __str__(self):
+        return self.name
 
 
 class DebPackageInstalled(Matcher):
@@ -28,18 +28,18 @@ class DebPackageInstalled(Matcher):
     def _matches(self, package):
         self.package = package
 
-        out = StringIO()
+        out = BytesIO()
         sp = SubProcess('dpkg -l %s | grep ^ii' % self.package.name,
                         stdout=out, shell=True)
         retval = not sp.wait()
 
         if retval and self.version is not None:
-            installed = out.getvalue().split()[2].strip()
+            installed = out.getvalue().decode(errors='ignore').split()[2].strip()
             retval &= installed >= self.version
 
-#            Log.debug("%s: pkg:%s inst:%s req:%s" %
-#                      (self.__class__.__name__, self.package,
-#                       installed, self.version))
+            print("%s: pkg:%s inst:%s req:%s" %
+                  (self.__class__.__name__, self.package,
+                   installed, self.version))
 
         return retval
 
