@@ -1,4 +1,3 @@
-#!/usr/bin/python
 # -*- coding:utf-8; tab-width:4; mode:python -*-
 
 from hamcrest import is_not
@@ -16,5 +15,5 @@ class Debian(TestCase):
 
     def test_installed_version(self):
         depends = Task()
-        depends.assert_that(Package('python-prego'),
-                            installed(min_version='0.20130206'))
+        depends.assert_that(Package('bash'),
+                            installed(min_version='3.0'))
